from logging import getLogger

from gettext import install

install(__name__)

logger = getLogger(__name__)


def show_projection(experiment: "Experiment") -> None:
    """
    Show projection data with matplotlib
    """
    logger.debug(_("showing experiment result"))
    from matplotlib.pyplot import loglog, show, legend, close

    excited = experiment.signals["excited"].psd().sqrt()
    reference = experiment.signals["reference"].psd().sqrt()
    loglog(
        experiment.projection.x,
        experiment.projection.y,
        label="projection",
    )  # type: ignore[ReportUnusedCallResult]
    loglog(excited.x, excited.y, label="excited bench")  # type: ignore[ReportUnusedCallResult]
    loglog(reference.x, reference.y, label="reference bench")  # type: ignore[ReportUnusedCallResult]
    loglog(
        (experiment.projection + reference).x,
        (experiment.projection + reference).y,
        label="sum reference + excited",
    )  # type: ignore[ReportUnusedCallResult]
    legend()  # type: ignore[ReportUnusedCallResult]
    show()
    close()
    logger.debug(_("experiment result showed"))
